@@ -6,8 +6,12 @@ use warnings;
 use charnames qw( :full );
 use parent 'Exporter';
 
-our $VERSION = '0.02';
-our @EXPORT  = qw( dump_string );
+our $VERSION = '0.03';
+our @EXPORT  = qw( dumpstr dump_string );
+# TODO: remove dump_string from @EXPORT
+#our @EXPORT_OK = qw( dump_string );
+
+*dump_string = \&dumpstr;
 
 use constant DEFAULT_MODE => 'hex';
 
@@ -27,7 +31,7 @@ my %sub_for = (
     names => sub { map { charnames::viacode ord } @_ },
 );
 
-sub dump_string {
+sub dumpstr {
     my ($mode, $string);
 
     if (@_ == 1) {
@@ -54,30 +58,31 @@ String::Dump - Dump strings of characters or bytes for printing and debugging
 
 =head1 VERSION
 
-This document describes String::Dump version 0.02.
+This document describes String::Dump version 0.03.
 
 =head1 SYNOPSIS
 
     use String::Dump;
 
-    say 'hex: ', dump_string($string);  # hex mode by default
-    say 'oct: ', dump_string(oct => $string);  # octal mode
+    say 'hex: ', dumpstr($string);  # hex mode by default
+    say 'oct: ', dumpstr(oct => $string);  # octal mode
 
 =head1 DESCRIPTION
 
-This module provides the function C<dump_string> and exports it by default.
-When debugging or reviewing non-ASCII data, C<dump_string> is your friend.
-It's a simple utility to view the characters or bytes of your string in
-several different formats, such as hex, octal, decimal, Unicode names, and
-more.
+This module provides the C<dumpstr> function and exports it by default.  Those
+who prefer their function names unabridged may manually export C<dump_string>
+instead.  When debugging or reviewing strings containing non-ASCII or
+non-printing characters, C<dumpstr> is your friend.  It's a simple utility to
+view the characters or bytes of your string in several different formats, such
+as hex, octal, decimal, Unicode names, and more.
 
 An OO interface is forthcoming with additional options and the ability to
-reuse them among multiple calls.  Some benefits will be the ability to set
-the delimiter between characters and to force a string to be treated as a
-string of characters or a series of bytes.  Don't worry, the C<dump_string>
-function will remain simple.
+reuse them among multiple calls.  Some benefits will include the ability to
+set the delimiter between characters, set padding for the characters, and
+force a string to be treated as a string of characters or a series of bytes.
+Don't worry, the C<dumpstr> function will remain simple.
 
-=head2 dump_string($mode, $string)
+=head2 dumpstr($mode, $string)
 
 The mode is optional and defaults to C<hex>.  Other valid modes are C<dec>,
 C<oct>, C<bin>, and C<names>, and are described below.  The string may either
@@ -92,47 +97,47 @@ without the mode.
 
     use utf8;
     # string of 6 characters
-    say dump_string('Ĝis! ☺');  # 11C 69 73 21 20 263A
-    say dump_string(hex => 'Ĝis! ☺');  # same thing
+    say dumpstr('Ĝis! ☺');  # 11C 69 73 21 20 263A
+    say dumpstr(hex => 'Ĝis! ☺');  # same thing
 
     no utf8;
     # series of 9 bytes
-    say dump_string('Ĝis! ☺');  # C4 9C 69 73 21 20 E2 98 BA
+    say dumpstr('Ĝis! ☺');  # C4 9C 69 73 21 20 E2 98 BA
 
 For a lowercase hex dump, simply pass the response to C<lc>.
 
-    say lc dump_string('Ĝis! ☺');  # 11c 69 73 21 20 263a
+    say lc dumpstr('Ĝis! ☺');  # 11c 69 73 21 20 263a
 
 =head3 dec
 
 Decimal (base 10) mode.
 
     use utf8;
-    say dump_string(dec => 'Ĝis! ☺');  # 284 105 115 33 32 9786
+    say dumpstr(dec => 'Ĝis! ☺');  # 284 105 115 33 32 9786
 
     no utf8;
-    say dump_string(dec => 'Ĝis! ☺');  # 196 156 105 115 33 32 226 152 186
+    say dumpstr(dec => 'Ĝis! ☺');  # 196 156 105 115 33 32 226 152 186
 
 =head3 oct
 
 Octal (base 8) mode.
 
     use utf8;
-    say dump_string(oct => 'Ĝis! ☺');  # 434 151 163 41 40 23072
+    say dumpstr(oct => 'Ĝis! ☺');  # 434 151 163 41 40 23072
 
     no utf8;
-    say dump_string(oct => 'Ĝis! ☺');  # 304 234 151 163 41 40 342 230 272
+    say dumpstr(oct => 'Ĝis! ☺');  # 304 234 151 163 41 40 342 230 272
 
 =head3 bin
 
 Binary (base 2) mode.
 
     use utf8;
-    say dump_string(bin => 'Ĝis! ☺');
+    say dumpstr(bin => 'Ĝis! ☺');
     # 100011100 1101001 1110011 100001 100000 10011000111010
 
     no utf8;
-    say dump_string(bin => 'Ĝis! ☺');
+    say dumpstr(bin => 'Ĝis! ☺');
     # 11000100 10011100 1101001 1110011 100001 100000 11100010 10011000 10111010
 
 =head3 names
@@ -141,7 +146,7 @@ Named Unicode character mode.  Unlike the various numeral modes above, this
 mode uses ', ' for the delimiter.
 
     use utf8;
-    say dump_string(names => 'Ĝis! ☺');
+    say dumpstr(names => 'Ĝis! ☺');
     # LATIN CAPITAL LETTER G WITH CIRCUMFLEX, LATIN SMALL LETTER I,
     # LATIN SMALL LETTER S, EXCLAMATION MARK, SPACE, WHITE SMILING FACE
 
@@ -149,7 +154,7 @@ This mode makes no sense for a series of bytes, but it still works if that's
 what you really want!
 
     no utf8;
-    say dump_string(names => 'Ĝis! ☺');
+    say dumpstr(names => 'Ĝis! ☺');
     # LATIN CAPITAL LETTER A WITH DIAERESIS, STRING TERMINATOR,
     # LATIN SMALL LETTER I, LATIN SMALL LETTER S, EXCLAMATION MARK,
     # SPACE, LATIN SMALL LETTER A WITH CIRCUMFLEX, START OF STRING,
@@ -171,10 +176,10 @@ lexically enabled or disabled.
 
     {
         no utf8;
-        say dump_string('Ĝis! ☺');  # C4 9C 69 73 21 20 E2 98 BA
+        say dumpstr('Ĝis! ☺');  # C4 9C 69 73 21 20 E2 98 BA
     }
 
-    say dump_string('Ĝis! ☺');  # 11C 69 73 21 20 263A
+    say dumpstr('Ĝis! ☺');  # 11C 69 73 21 20 263A
 
 =head3 Command-line input and filehandles
 
@@ -192,13 +197,13 @@ L<Encode::decode_utf8|Encode>, which will return the desired string.
 
     use Encode;
 
-    say dump_string( decode_utf8($string) );
+    say dumpstr( decode_utf8($string) );
 
 To convert a variable in-place, pass it to utf8::decode instead.
 
     utf8::decode($string);
 
-    say dump_string($string);
+    say dumpstr($string);
 
 =head1 CONTRIBUTIONS
 
